![Screenshot of ships in ATAK, via AISCOT.](https://aiscot.readthedocs.io/en/latest/media/aiscot_screenshot_tak_logo.png)

# Display Ships in TAK - AIS to TAK Gateway 

## Features

- Real-time AIS data capture and reporting
- Integration with TAK products using native protocols
- Compatibility with ATAK, WinTAK, iTAK, TAK Server & TAKX
- Support for RF AIS transmissions, local NMEA, and Internet AIS aggregators
- Display of AIS data with icons, attitude, type, track, bearing, speed, callsign, and more

## Use Case

Originally developed to support an [open ocean boat race in the Northern Pacific Ocean](http://ampledata.org/boat_race_support.html).

## Documentation

[AISCOT documentation is available here.](https://aiscot.rtfd.io)

## License & Copyright

Copyright Sensors & Signals LLC https://www.snstac.com

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at [http://www.apache.org/licenses/LICENSE-2.0](http://www.apache.org/licenses/LICENSE-2.0)

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

* pyAISm.py is licensed under the MIT License. See aiscot/pyAISm.py for details.
